from ....tl.mtproto_request import MTProtoRequest


class SavedGifsNotModified(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    messages.savedGifsNotModified#e8025ca2  = messages.SavedGifs"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe8025ca2

    def __init__(self):
        super().__init__()

    def on_send(self, writer):
        writer.write_int(SavedGifsNotModified.constructor_id, signed=False)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return SavedGifsNotModified()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'messages.savedGifsNotModified#e8025ca2  = messages.SavedGifs'

    def __str__(self):
        return '(messages.savedGifsNotModified (ID: 0xe8025ca2) = ())'.format()
