from ...tl.mtproto_request import MTProtoRequest


class InputBotInlineMessageID(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputBotInlineMessageID#890c3d89 dc_id:int id:long access_hash:long = InputBotInlineMessageID"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x890c3d89

    def __init__(self, dc_id, id, access_hash):
        """
        :param dc_id: Telegram type: «int».
        :param id: Telegram type: «long».
        :param access_hash: Telegram type: «long».

        Constructor for InputBotInlineMessageID: Instance of InputBotInlineMessageID.
        """
        super().__init__()

        self.dc_id = dc_id
        self.id = id
        self.access_hash = access_hash

    def on_send(self, writer):
        writer.write_int(InputBotInlineMessageID.constructor_id, signed=False)
        writer.write_int(self.dc_id)
        writer.write_long(self.id)
        writer.write_long(self.access_hash)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputBotInlineMessageID(None, None, None)

    def on_response(self, reader):
        self.dc_id = reader.read_int()
        self.id = reader.read_long()
        self.access_hash = reader.read_long()

    def __repr__(self):
        return 'inputBotInlineMessageID#890c3d89 dc_id:int id:long access_hash:long = InputBotInlineMessageID'

    def __str__(self):
        return '(inputBotInlineMessageID (ID: 0x890c3d89) = (dc_id={}, id={}, access_hash={}))'.format(str(self.dc_id), str(self.id), str(self.access_hash))
