from ...tl.mtproto_request import MTProtoRequest


class UpdateEncryptedMessagesRead(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateEncryptedMessagesRead#38fe25b7 chat_id:int max_date:date date:date = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x38fe25b7

    def __init__(self, chat_id, max_date, date):
        """
        :param chat_id: Telegram type: «int».
        :param max_date: Telegram type: «date».
        :param date: Telegram type: «date».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.chat_id = chat_id
        self.max_date = max_date
        self.date = date

    def on_send(self, writer):
        writer.write_int(UpdateEncryptedMessagesRead.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        writer.tgwrite_date(self.max_date)
        writer.tgwrite_date(self.date)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateEncryptedMessagesRead(None, None, None)

    def on_response(self, reader):
        self.chat_id = reader.read_int()
        self.max_date = reader.tgread_date()
        self.date = reader.tgread_date()

    def __repr__(self):
        return 'updateEncryptedMessagesRead#38fe25b7 chat_id:int max_date:date date:date = Update'

    def __str__(self):
        return '(updateEncryptedMessagesRead (ID: 0x38fe25b7) = (chat_id={}, max_date={}, date={}))'.format(str(self.chat_id), str(self.max_date), str(self.date))
