from .get_config import GetConfigRequest
from .get_nearest_dc import GetNearestDcRequest
from .get_app_update import GetAppUpdateRequest
from .save_app_log import SaveAppLogRequest
from .get_invite_text import GetInviteTextRequest
from .get_support import GetSupportRequest
from .get_app_changelog import GetAppChangelogRequest
from .get_terms_of_service import GetTermsOfServiceRequest
from .set_bot_updates_status import SetBotUpdatesStatusRequest
from .get_cdn_config import GetCdnConfigRequest
