from .read_history import ReadHistoryRequest
from .delete_messages import DeleteMessagesRequest
from .delete_user_history import DeleteUserHistoryRequest
from .report_spam import ReportSpamRequest
from .get_messages import GetMessagesRequest
from .get_participants import GetParticipantsRequest
from .get_participant import GetParticipantRequest
from .get_channels import GetChannelsRequest
from .get_full_channel import GetFullChannelRequest
from .create_channel import CreateChannelRequest
from .edit_about import EditAboutRequest
from .edit_admin import EditAdminRequest
from .edit_title import EditTitleRequest
from .edit_photo import EditPhotoRequest
from .check_username import CheckUsernameRequest
from .update_username import UpdateUsernameRequest
from .join_channel import JoinChannelRequest
from .leave_channel import LeaveChannelRequest
from .invite_to_channel import InviteToChannelRequest
from .kick_from_channel import KickFromChannelRequest
from .export_invite import ExportInviteRequest
from .delete_channel import DeleteChannelRequest
from .toggle_invites import ToggleInvitesRequest
from .export_message_link import ExportMessageLinkRequest
from .toggle_signatures import ToggleSignaturesRequest
from .update_pinned_message import UpdatePinnedMessageRequest
from .get_admined_public_channels import GetAdminedPublicChannelsRequest
