from ....tl.mtproto_request import MTProtoRequest


class ChannelDifference(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updates.channelDifference#2064674e flags:# final:flags.0?true pts:int timeout:flags.1?int new_messages:Vector<Message> other_updates:Vector<Update> chats:Vector<Chat> users:Vector<User> = updates.ChannelDifference"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x2064674e

    def __init__(self, pts, new_messages, other_updates, chats, users, final=None, timeout=None):
        """
        :param final: Telegram type: «true».
        :param pts: Telegram type: «int».
        :param timeout: Telegram type: «int».
        :param new_messages: Telegram type: «Message». Must be a list.
        :param other_updates: Telegram type: «Update». Must be a list.
        :param chats: Telegram type: «Chat». Must be a list.
        :param users: Telegram type: «User». Must be a list.

        Constructor for updates.ChannelDifference: Instance of either ChannelDifferenceEmpty, ChannelDifferenceTooLong, ChannelDifference.
        """
        super().__init__()

        self.final = final
        self.pts = pts
        self.timeout = timeout
        self.new_messages = new_messages
        self.other_updates = other_updates
        self.chats = chats
        self.users = users

    def on_send(self, writer):
        writer.write_int(ChannelDifference.constructor_id, signed=False)
        # Calculate the flags. This equals to those flag arguments which are NOT None
        flags = 0
        flags |= (1 << 0) if self.final else 0
        flags |= (1 << 1) if self.timeout else 0
        writer.write_int(flags)

        writer.write_int(self.pts)
        if self.timeout:
            writer.write_int(self.timeout)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.new_messages))
        for new_messages_item in self.new_messages:
            new_messages_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.other_updates))
        for other_updates_item in self.other_updates:
            other_updates_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.chats))
        for chats_item in self.chats:
            chats_item.on_send(writer)

        writer.write_int(0x1cb5c415, signed=False)  # Vector's constructor ID
        writer.write_int(len(self.users))
        for users_item in self.users:
            users_item.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return ChannelDifference(None, None, None, None, None, None, None)

    def on_response(self, reader):
        flags = reader.read_int()

        if (flags & (1 << 0)) != 0:
            self.final = True  # Arbitrary not-None value, no need to read since it is a flag

        self.pts = reader.read_int()
        if (flags & (1 << 1)) != 0:
            self.timeout = reader.read_int()

        reader.read_int()  # Vector's constructor ID
        self.new_messages = []  # Initialize an empty list
        new_messages_len = reader.read_int()
        for _ in range(new_messages_len):
            new_messages_item = reader.tgread_object()
            self.new_messages.append(new_messages_item)

        reader.read_int()  # Vector's constructor ID
        self.other_updates = []  # Initialize an empty list
        other_updates_len = reader.read_int()
        for _ in range(other_updates_len):
            other_updates_item = reader.tgread_object()
            self.other_updates.append(other_updates_item)

        reader.read_int()  # Vector's constructor ID
        self.chats = []  # Initialize an empty list
        chats_len = reader.read_int()
        for _ in range(chats_len):
            chats_item = reader.tgread_object()
            self.chats.append(chats_item)

        reader.read_int()  # Vector's constructor ID
        self.users = []  # Initialize an empty list
        users_len = reader.read_int()
        for _ in range(users_len):
            users_item = reader.tgread_object()
            self.users.append(users_item)

    def __repr__(self):
        return 'updates.channelDifference#2064674e flags:# final:flags.0?true pts:int timeout:flags.1?int new_messages:Vector<Message> other_updates:Vector<Update> chats:Vector<Chat> users:Vector<User> = updates.ChannelDifference'

    def __str__(self):
        return '(updates.channelDifference (ID: 0x2064674e) = (final={}, pts={}, timeout={}, new_messages={}, other_updates={}, chats={}, users={}))'.format(str(self.final), str(self.pts), str(self.timeout), None if not self.new_messages else [str(_) for _ in self.new_messages], None if not self.other_updates else [str(_) for _ in self.other_updates], None if not self.chats else [str(_) for _ in self.chats], None if not self.users else [str(_) for _ in self.users])
