from .get_statuses import GetStatusesRequest
from .get_contacts import GetContactsRequest
from .import_contacts import ImportContactsRequest
from .delete_contact import DeleteContactRequest
from .delete_contacts import DeleteContactsRequest
from .block import BlockRequest
from .unblock import UnblockRequest
from .get_blocked import GetBlockedRequest
from .export_card import ExportCardRequest
from .import_card import ImportCardRequest
from .search import SearchRequest
from .resolve_username import ResolveUsernameRequest
from .get_top_peers import GetTopPeersRequest
from .reset_top_peer_rating import ResetTopPeerRatingRequest
