from .register_device import RegisterDeviceRequest
from .unregister_device import UnregisterDeviceRequest
from .update_notify_settings import UpdateNotifySettingsRequest
from .get_notify_settings import GetNotifySettingsRequest
from .reset_notify_settings import ResetNotifySettingsRequest
from .update_profile import UpdateProfileRequest
from .update_status import UpdateStatusRequest
from .get_wall_papers import GetWallPapersRequest
from .report_peer import ReportPeerRequest
from .check_username import CheckUsernameRequest
from .update_username import UpdateUsernameRequest
from .get_privacy import GetPrivacyRequest
from .set_privacy import SetPrivacyRequest
from .delete_account import DeleteAccountRequest
from .get_account_ttl import GetAccountTTLRequest
from .set_account_ttl import SetAccountTTLRequest
from .send_change_phone_code import SendChangePhoneCodeRequest
from .change_phone import ChangePhoneRequest
from .update_device_locked import UpdateDeviceLockedRequest
from .get_authorizations import GetAuthorizationsRequest
from .reset_authorization import ResetAuthorizationRequest
from .get_password import GetPasswordRequest
from .get_password_settings import GetPasswordSettingsRequest
from .update_password_settings import UpdatePasswordSettingsRequest
from .send_confirm_phone_code import SendConfirmPhoneCodeRequest
from .confirm_phone import ConfirmPhoneRequest
from .get_tmp_password import GetTmpPasswordRequest
