from ...tl.mtproto_request import MTProtoRequest


class UpdateUserStatus(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserStatus#1bfbd823 user_id:int status:UserStatus = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x1bfbd823

    def __init__(self, user_id, status):
        """
        :param user_id: Telegram type: «int».
        :param status: Telegram type: «UserStatus».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.status = status

    def on_send(self, writer):
        writer.write_int(UpdateUserStatus.constructor_id, signed=False)
        writer.write_int(self.user_id)
        self.status.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserStatus(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.status = reader.tgread_object()

    def __repr__(self):
        return 'updateUserStatus#1bfbd823 user_id:int status:UserStatus = Update'

    def __str__(self):
        return '(updateUserStatus (ID: 0x1bfbd823) = (user_id={}, status={}))'.format(str(self.user_id), str(self.status))
