from ...tl.mtproto_request import MTProtoRequest


class InputStickerSetEmpty(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    inputStickerSetEmpty#ffb62b95  = InputStickerSet"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xffb62b95

    def __init__(self):
        super().__init__()

    def on_send(self, writer):
        writer.write_int(InputStickerSetEmpty.constructor_id, signed=False)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return InputStickerSetEmpty()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'inputStickerSetEmpty#ffb62b95  = InputStickerSet'

    def __str__(self):
        return '(inputStickerSetEmpty (ID: 0xffb62b95) = ())'.format()
