from ...tl.mtproto_request import MTProtoRequest


class UpdateChannelMessageViews(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateChannelMessageViews#98a12b4b channel_id:int id:int views:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x98a12b4b

    def __init__(self, channel_id, id, views):
        """
        :param channel_id: Telegram type: «int».
        :param id: Telegram type: «int».
        :param views: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.channel_id = channel_id
        self.id = id
        self.views = views

    def on_send(self, writer):
        writer.write_int(UpdateChannelMessageViews.constructor_id, signed=False)
        writer.write_int(self.channel_id)
        writer.write_int(self.id)
        writer.write_int(self.views)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateChannelMessageViews(None, None, None)

    def on_response(self, reader):
        self.channel_id = reader.read_int()
        self.id = reader.read_int()
        self.views = reader.read_int()

    def __repr__(self):
        return 'updateChannelMessageViews#98a12b4b channel_id:int id:int views:int = Update'

    def __str__(self):
        return '(updateChannelMessageViews (ID: 0x98a12b4b) = (channel_id={}, id={}, views={}))'.format(str(self.channel_id), str(self.id), str(self.views))
