from .dialogs import Dialogs
from .dialogs_slice import DialogsSlice
from .messages import Messages
from .messages_slice import MessagesSlice
from .channel_messages import ChannelMessages
from .chats import Chats
from .chats_slice import ChatsSlice
from .chat_full import ChatFull
from .affected_history import AffectedHistory
from .dh_config_not_modified import DhConfigNotModified
from .dh_config import DhConfig
from .sent_encrypted_message import SentEncryptedMessage
from .sent_encrypted_file import SentEncryptedFile
from .stickers_not_modified import StickersNotModified
from .stickers import Stickers
from .all_stickers_not_modified import AllStickersNotModified
from .all_stickers import AllStickers
from .affected_messages import AffectedMessages
from .sticker_set import StickerSet
from .found_gifs import FoundGifs
from .saved_gifs_not_modified import SavedGifsNotModified
from .saved_gifs import SavedGifs
from .bot_results import BotResults
from .bot_callback_answer import BotCallbackAnswer
from .message_edit_data import MessageEditData
from .peer_dialogs import PeerDialogs
from .featured_stickers_not_modified import FeaturedStickersNotModified
from .featured_stickers import FeaturedStickers
from .recent_stickers_not_modified import RecentStickersNotModified
from .recent_stickers import RecentStickers
from .archived_stickers import ArchivedStickers
from .sticker_set_install_result_success import StickerSetInstallResultSuccess
from .sticker_set_install_result_archive import StickerSetInstallResultArchive
from .high_scores import HighScores
