from ...tl.mtproto_request import MTProtoRequest


class UpdateUserPhone(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateUserPhone#12b9417b user_id:int phone:string = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x12b9417b

    def __init__(self, user_id, phone):
        """
        :param user_id: Telegram type: «int».
        :param phone: Telegram type: «string».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.user_id = user_id
        self.phone = phone

    def on_send(self, writer):
        writer.write_int(UpdateUserPhone.constructor_id, signed=False)
        writer.write_int(self.user_id)
        writer.tgwrite_string(self.phone)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateUserPhone(None, None)

    def on_response(self, reader):
        self.user_id = reader.read_int()
        self.phone = reader.tgread_string()

    def __repr__(self):
        return 'updateUserPhone#12b9417b user_id:int phone:string = Update'

    def __str__(self):
        return '(updateUserPhone (ID: 0x12b9417b) = (user_id={}, phone={}))'.format(str(self.user_id), str(self.phone))
