from .get_messages import GetMessagesRequest
from .get_dialogs import GetDialogsRequest
from .get_history import GetHistoryRequest
from .search import SearchRequest
from .read_history import ReadHistoryRequest
from .delete_history import DeleteHistoryRequest
from .delete_messages import DeleteMessagesRequest
from .received_messages import ReceivedMessagesRequest
from .set_typing import SetTypingRequest
from .send_message import SendMessageRequest
from .send_media import SendMediaRequest
from .forward_messages import ForwardMessagesRequest
from .report_spam import ReportSpamRequest
from .hide_report_spam import HideReportSpamRequest
from .get_peer_settings import GetPeerSettingsRequest
from .get_chats import GetChatsRequest
from .get_full_chat import GetFullChatRequest
from .edit_chat_title import EditChatTitleRequest
from .edit_chat_photo import EditChatPhotoRequest
from .add_chat_user import AddChatUserRequest
from .delete_chat_user import DeleteChatUserRequest
from .create_chat import CreateChatRequest
from .forward_message import ForwardMessageRequest
from .get_dh_config import GetDhConfigRequest
from .request_encryption import RequestEncryptionRequest
from .accept_encryption import AcceptEncryptionRequest
from .discard_encryption import DiscardEncryptionRequest
from .set_encrypted_typing import SetEncryptedTypingRequest
from .read_encrypted_history import ReadEncryptedHistoryRequest
from .send_encrypted import SendEncryptedRequest
from .send_encrypted_file import SendEncryptedFileRequest
from .send_encrypted_service import SendEncryptedServiceRequest
from .received_queue import ReceivedQueueRequest
from .report_encrypted_spam import ReportEncryptedSpamRequest
from .read_message_contents import ReadMessageContentsRequest
from .get_all_stickers import GetAllStickersRequest
from .get_web_page_preview import GetWebPagePreviewRequest
from .export_chat_invite import ExportChatInviteRequest
from .check_chat_invite import CheckChatInviteRequest
from .import_chat_invite import ImportChatInviteRequest
from .get_sticker_set import GetStickerSetRequest
from .install_sticker_set import InstallStickerSetRequest
from .uninstall_sticker_set import UninstallStickerSetRequest
from .start_bot import StartBotRequest
from .get_messages_views import GetMessagesViewsRequest
from .toggle_chat_admins import ToggleChatAdminsRequest
from .edit_chat_admin import EditChatAdminRequest
from .migrate_chat import MigrateChatRequest
from .search_global import SearchGlobalRequest
from .reorder_sticker_sets import ReorderStickerSetsRequest
from .get_document_by_hash import GetDocumentByHashRequest
from .search_gifs import SearchGifsRequest
from .get_saved_gifs import GetSavedGifsRequest
from .save_gif import SaveGifRequest
from .get_inline_bot_results import GetInlineBotResultsRequest
from .set_inline_bot_results import SetInlineBotResultsRequest
from .send_inline_bot_result import SendInlineBotResultRequest
from .get_message_edit_data import GetMessageEditDataRequest
from .edit_message import EditMessageRequest
from .edit_inline_bot_message import EditInlineBotMessageRequest
from .get_bot_callback_answer import GetBotCallbackAnswerRequest
from .set_bot_callback_answer import SetBotCallbackAnswerRequest
from .get_peer_dialogs import GetPeerDialogsRequest
from .save_draft import SaveDraftRequest
from .get_all_drafts import GetAllDraftsRequest
from .get_featured_stickers import GetFeaturedStickersRequest
from .read_featured_stickers import ReadFeaturedStickersRequest
from .get_recent_stickers import GetRecentStickersRequest
from .save_recent_sticker import SaveRecentStickerRequest
from .clear_recent_stickers import ClearRecentStickersRequest
from .get_archived_stickers import GetArchivedStickersRequest
from .get_mask_stickers import GetMaskStickersRequest
from .get_attached_stickers import GetAttachedStickersRequest
from .set_game_score import SetGameScoreRequest
from .set_inline_game_score import SetInlineGameScoreRequest
from .get_game_high_scores import GetGameHighScoresRequest
from .get_inline_game_high_scores import GetInlineGameHighScoresRequest
from .get_common_chats import GetCommonChatsRequest
from .get_all_chats import GetAllChatsRequest
from .get_web_page import GetWebPageRequest
from .toggle_dialog_pin import ToggleDialogPinRequest
from .reorder_pinned_dialogs import ReorderPinnedDialogsRequest
from .get_pinned_dialogs import GetPinnedDialogsRequest
from .set_bot_shipping_results import SetBotShippingResultsRequest
from .set_bot_precheckout_results import SetBotPrecheckoutResultsRequest
