from ....tl.mtproto_request import MTProtoRequest


class CodeTypeFlashCall(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    auth.codeTypeFlashCall#226ccefb  = auth.CodeType"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x226ccefb

    def __init__(self):
        super().__init__()

    def on_send(self, writer):
        writer.write_int(CodeTypeFlashCall.constructor_id, signed=False)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return CodeTypeFlashCall()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'auth.codeTypeFlashCall#226ccefb  = auth.CodeType'

    def __str__(self):
        return '(auth.codeTypeFlashCall (ID: 0x226ccefb) = ())'.format()
