from ...tl.mtproto_request import MTProtoRequest


class PhoneCallDiscardReasonMissed(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    phoneCallDiscardReasonMissed#85e42301  = PhoneCallDiscardReason"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x85e42301

    def __init__(self):
        super().__init__()

    def on_send(self, writer):
        writer.write_int(PhoneCallDiscardReasonMissed.constructor_id, signed=False)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return PhoneCallDiscardReasonMissed()

    def on_response(self, reader):
        pass

    def __repr__(self):
        return 'phoneCallDiscardReasonMissed#85e42301  = PhoneCallDiscardReason'

    def __str__(self):
        return '(phoneCallDiscardReasonMissed (ID: 0x85e42301) = ())'.format()
