from ...tl.mtproto_request import MTProtoRequest


class UpdateBotShippingQuery(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateBotShippingQuery#e0cdc940 query_id:long user_id:int payload:bytes shipping_address:PostAddress = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0xe0cdc940

    def __init__(self, query_id, user_id, payload, shipping_address):
        """
        :param query_id: Telegram type: «long».
        :param user_id: Telegram type: «int».
        :param payload: Telegram type: «bytes».
        :param shipping_address: Telegram type: «PostAddress».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.query_id = query_id
        self.user_id = user_id
        self.payload = payload
        self.shipping_address = shipping_address

    def on_send(self, writer):
        writer.write_int(UpdateBotShippingQuery.constructor_id, signed=False)
        writer.write_long(self.query_id)
        writer.write_int(self.user_id)
        writer.tgwrite_bytes(self.payload)
        self.shipping_address.on_send(writer)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateBotShippingQuery(None, None, None, None)

    def on_response(self, reader):
        self.query_id = reader.read_long()
        self.user_id = reader.read_int()
        self.payload = reader.tgread_bytes()
        self.shipping_address = reader.tgread_object()

    def __repr__(self):
        return 'updateBotShippingQuery#e0cdc940 query_id:long user_id:int payload:bytes shipping_address:PostAddress = Update'

    def __str__(self):
        return '(updateBotShippingQuery (ID: 0xe0cdc940) = (query_id={}, user_id={}, payload={}, shipping_address={}))'.format(str(self.query_id), str(self.user_id), str(self.payload), str(self.shipping_address))
