from ...tl.mtproto_request import MTProtoRequest


class UpdateChatParticipantDelete(MTProtoRequest):
    """Class generated by TLObjects' generator. All changes will be ERASED. Original .tl definition below.
    updateChatParticipantDelete#6e5f8c22 chat_id:int user_id:int version:int = Update"""

    # Telegram's constructor ID (and unique identifier) for this class
    constructor_id = 0x6e5f8c22

    def __init__(self, chat_id, user_id, version):
        """
        :param chat_id: Telegram type: «int».
        :param user_id: Telegram type: «int».
        :param version: Telegram type: «int».

        Constructor for Update: Instance of either UpdateNewMessage, UpdateMessageID, UpdateDeleteMessages, UpdateUserTyping, UpdateChatUserTyping, UpdateChatParticipants, UpdateUserStatus, UpdateUserName, UpdateUserPhoto, UpdateContactRegistered, UpdateContactLink, UpdateNewEncryptedMessage, UpdateEncryptedChatTyping, UpdateEncryption, UpdateEncryptedMessagesRead, UpdateChatParticipantAdd, UpdateChatParticipantDelete, UpdateDcOptions, UpdateUserBlocked, UpdateNotifySettings, UpdateServiceNotification, UpdatePrivacy, UpdateUserPhone, UpdateReadHistoryInbox, UpdateReadHistoryOutbox, UpdateWebPage, UpdateReadMessagesContents, UpdateChannelTooLong, UpdateChannel, UpdateNewChannelMessage, UpdateReadChannelInbox, UpdateDeleteChannelMessages, UpdateChannelMessageViews, UpdateChatAdmins, UpdateChatParticipantAdmin, UpdateNewStickerSet, UpdateStickerSetsOrder, UpdateStickerSets, UpdateSavedGifs, UpdateBotInlineQuery, UpdateBotInlineSend, UpdateEditChannelMessage, UpdateChannelPinnedMessage, UpdateBotCallbackQuery, UpdateEditMessage, UpdateInlineBotCallbackQuery, UpdateReadChannelOutbox, UpdateDraftMessage, UpdateReadFeaturedStickers, UpdateRecentStickers, UpdateConfig, UpdatePtsChanged, UpdateChannelWebPage, UpdateDialogPinned, UpdatePinnedDialogs, UpdateBotWebhookJSON, UpdateBotWebhookJSONQuery, UpdateBotShippingQuery, UpdateBotPrecheckoutQuery, UpdatePhoneCall.
        """
        super().__init__()

        self.chat_id = chat_id
        self.user_id = user_id
        self.version = version

    def on_send(self, writer):
        writer.write_int(UpdateChatParticipantDelete.constructor_id, signed=False)
        writer.write_int(self.chat_id)
        writer.write_int(self.user_id)
        writer.write_int(self.version)

    @staticmethod
    def empty():
        """Returns an "empty" instance (all attributes are None)"""
        return UpdateChatParticipantDelete(None, None, None)

    def on_response(self, reader):
        self.chat_id = reader.read_int()
        self.user_id = reader.read_int()
        self.version = reader.read_int()

    def __repr__(self):
        return 'updateChatParticipantDelete#6e5f8c22 chat_id:int user_id:int version:int = Update'

    def __str__(self):
        return '(updateChatParticipantDelete (ID: 0x6e5f8c22) = (chat_id={}, user_id={}, version={}))'.format(str(self.chat_id), str(self.user_id), str(self.version))
